package at.xaxa.gamelibraryapp.data

import android.util.Log
import at.xaxa.gamelibraryapp.data.db.LibraryDao
import at.xaxa.gamelibraryapp.data.db.LibraryEntity
import at.xaxa.gamelibraryapp.data.remote.GameDto
import at.xaxa.gamelibraryapp.data.remote.GameRemoteService
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.withContext
import kotlin.math.log

class GameRepository(private val libraryDao: LibraryDao, private val gameRemoteService: GameRemoteService) {
    private val apiKey = "7a2a800a085d41e88621a8a59dc5ea82"

    suspend fun searchGames(searchText: String): List<GameDto> {
        return withContext(Dispatchers.IO) {
            try {
                print(gameRemoteService.searchGames(apiKey, searchText).toString())
                gameRemoteService.searchGames(apiKey, searchText).results
            } catch (e: Exception) {
                Log.e("GameRepository", "Error searching games from API: ${e.message}", e)
                emptyList<GameDto>()
            }
        }
    }

    fun getAllGamesInLibrary(): Flow<List<Game>> {
        return libraryDao.getAllEntries().map {
            it.map {item -> Game(item._id, item.name, item.details, item.note, item.imageUrl, item.inLibrary) }
        }
    }


    fun searchGameInDB(searchText: String):Flow<List<Game>>{
        return libraryDao.getEntriesWithName(searchText).map {
            it.map {item -> Game(item._id, item.name, item.details, item.note, item.imageUrl, item.inLibrary) }
        }
    }


    suspend fun findGameById(id: Int): LibraryEntity {
        val item = libraryDao.findEntryById(id)
            //?: throw GameNotFoundException("Game with id $id not found.")
        return item
    }

    suspend fun addEntry(libraryEntity: LibraryEntity) {
        libraryDao.addEntry(LibraryEntity(libraryEntity._id, libraryEntity.name, libraryEntity.details, libraryEntity.note, libraryEntity.imageUrl, libraryEntity.inLibrary))
    }

    suspend fun updateEntry(game: LibraryEntity) {
        libraryDao.updateEntry(LibraryEntity(game._id, game.name, game.details, game.note, game.imageUrl, game.inLibrary))
    }
}