package at.xaxa.gamelibraryapp.ui.Details

import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.FilledTonalButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.gamelibraryapp.ui.AppViewModelProvider
import at.xaxa.gamelibraryapp.ui.DetailCard
import at.xaxa.gamelibraryapp.ui.LayoutMediaText
import at.xaxa.gamelibraryapp.ui.ShowPicture

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun DetailView(
    viewModel: DetailsViewModel = viewModel(factory = AppViewModelProvider.Factory),
    modifier: Modifier = Modifier
) {
    val libraryEntity = viewModel.editUiState.libraryEntity

    val buttonText = if (libraryEntity.inLibrary) "Remove from library" else "Add to library"

    Column {
        DetailCard(modifier,
            title = libraryEntity.name,
            details = libraryEntity.details,
            imageUrl = libraryEntity.imageUrl,
            note = libraryEntity.note,
            onClick = {
                viewModel.updateGame(libraryEntity.copy(inLibrary = !libraryEntity.inLibrary))
            },
            buttonText = buttonText
        )
        OutlinedTextField(
                modifier = Modifier
                    .padding(horizontal = 16.dp, vertical = 4.dp)
                    .fillMaxSize(),
                shape = RoundedCornerShape(12.dp),
                colors = TextFieldDefaults.outlinedTextFieldColors(
                    focusedBorderColor = Color.DarkGray,
                    unfocusedBorderColor = Color.LightGray),
                value = libraryEntity.note,
                onValueChange = {
                    viewModel.updateGame(libraryEntity.copy(note = it))
                },
                label = { Text("Notes") }
        )
    }
}
