package at.xaxa.gamelibraryapp.ui.GameList

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.gamelibraryapp.ui.AppViewModelProvider
import at.xaxa.gamelibraryapp.ui.Details.DetailsViewModel
import at.xaxa.gamelibraryapp.ui.HorizontalCard
import kotlinx.coroutines.flow.count
import androidx.compose.foundation.lazy.items


@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun GameList(modifier: Modifier = Modifier,
             viewModel: GameListViewModel = viewModel(factory = AppViewModelProvider.Factory),
             onCardClick: (Int) -> Unit) {
    //val gameList = viewModel.editUiState.libraryEntity
    val gameListState by viewModel.editUiState.libraryEntity.collectAsState(initial = emptyList())
    var searchText by remember { mutableStateOf("") }
    viewModel.searchGamesInDB(searchText)

    Column(modifier = modifier) {
        // Search Bar
        OutlinedTextField(
            value = searchText,
            onValueChange = { searchText = it },
            label = { Text("Search games") },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp, vertical = 4.dp),
            colors = TextFieldDefaults.outlinedTextFieldColors(
                focusedBorderColor = Color.DarkGray,
                unfocusedBorderColor = Color.LightGray)
        )

        // Game List
        LazyColumn(modifier = Modifier.fillMaxSize()) {
            items(gameListState) { game ->
                HorizontalCard(
                    modifier = modifier,
                    title = game.name,
                    details = game.details,
                    imageUrl = game.imageUrl,
                    onClick = {
                        onCardClick(game.id)
                    }
                )
            }
        }
    }
}
