package at.xaxa.gamelibraryapp.ui.GameList

import android.util.Log
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import at.xaxa.gamelibraryapp.data.Game
import at.xaxa.gamelibraryapp.data.GameRepository
import at.xaxa.gamelibraryapp.data.db.LibraryEntity
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flowOf
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

data class GameListUi(
    val libraryEntity: Flow<List<Game>> = flowOf(emptyList())
)

class GameListViewModel(private val savedStateHandle: SavedStateHandle, private val gameRepository: GameRepository) : ViewModel() {

    var editUiState by mutableStateOf(GameListUi())
        private set

    init {
        viewModelScope.launch {
            val games = withContext(Dispatchers.IO) {
                gameRepository.getAllGamesInLibrary()
            }
            editUiState = GameListUi(games)
        }
    }

    fun searchGamesInDB(searchString: String) {
        viewModelScope.launch {
            val searchResults = withContext(Dispatchers.IO) {
                gameRepository.searchGameInDB("%$searchString%")
            }

            editUiState = GameListUi(searchResults)
        }
    }
}
