package at.xaxa.gamelibraryapp.ui.Search

import android.util.Log
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.gamelibraryapp.ui.AppViewModelProvider
import at.xaxa.gamelibraryapp.ui.HorizontalCard
import androidx.compose.foundation.lazy.items

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun SearchList(
    modifier: Modifier = Modifier,
    viewModel: SearchListViewModel = viewModel(factory = AppViewModelProvider.Factory),
    onCardClick: (Int) -> Unit
) {
    var searchText by remember { mutableStateOf("") }
    val gamesList by viewModel.editUiState.games.collectAsState(initial = emptyList())

    Column(modifier = modifier) {
        // Search field
        OutlinedTextField(
            value = searchText,
            onValueChange = {
                searchText = it
                // Call searchGames when text changes
                viewModel.searchGames(searchText)
            },
            label = { Text("Search games") },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp, vertical = 4.dp),
            colors = TextFieldDefaults.outlinedTextFieldColors(
                focusedBorderColor = Color.DarkGray,
                unfocusedBorderColor = Color.LightGray
            )
        )

        LazyColumn(modifier = Modifier.fillMaxSize()) {
            items(gamesList) { game ->
                HorizontalCard(modifier,
                    game.name,
                    game.details,
                    game.imageUrl,//"https://media.rawg.io/media/games/6e0/6e0c19bb111bd4fa20cf0eb72a049519.jpg",
                    onClick = {
                        viewModel.addGameToDB(game)
                        onCardClick(game.id)
                    }
                )
            }
        }
    }
}